==> thymeleaf-extras-shiro-1.1.0-sources.jar: at/pollux/thymeleaf/shiro/processor/attribute/LacksRoleAttrProcessor.java <==
/*****************************************************************************
 * Copyright (c) 2013, theborakompanioni (http://www.example.org)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 ****************************************************************************/
package at.pollux.thymeleaf.shiro.processor.attribute;

import org.thymeleaf.Arguments;
import org.thymeleaf.dom.Element;
import org.thymeleaf.processor.attr.AbstractConditionalVisibilityAttrProcessor;
import org.thymeleaf.util.StringUtils;
import org.thymeleaf.util.Validate;

import at.pollux.thymeleaf.shiro.dialect.ShiroFacade;

public class LacksRoleAttrProcessor extends AbstractConditionalVisibilityAttrProcessor {

    public static LacksRoleAttrProcessor create() {
        return new LacksRoleAttrProcessor();
    }

    private static final String ATTRIBUTE_NAME = "lacksRole";
    private static final int PRECEDENCE = 300;

    protected LacksRoleAttrProcessor() {
        super(ATTRIBUTE_NAME);
    }

    @Override
    public int getPrecedence() {
        return PRECEDENCE;
    }

    @Override
    public boolean isVisible(final Arguments arguments, final Element element, final String attributeName) {
        Validate.notNull(element, "element must not be null");
        Validate.notEmpty(attributeName, "attributeName must not be empty");

        final String role = StringUtils.trim(element.getAttributeValue(attributeName));
        Validate.notEmpty(role, "value of '" + attributeName + "' must not be empty");

        return ShiroFacade.lacksRole(role);
    }
}

==> thymeleaf-extras-shiro-1.2.1-sources.jar: at/pollux/thymeleaf/shiro/processor/attribute/LacksRoleAttrProcessor.java <==
/*****************************************************************************
 * Copyright (c) 2013, theborakompanioni (http://www.example.org)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 ****************************************************************************/
package at.pollux.thymeleaf.shiro.processor.attribute;

import org.thymeleaf.Arguments;
import org.thymeleaf.dom.Element;
import org.thymeleaf.processor.attr.AbstractConditionalVisibilityAttrProcessor;

import at.pollux.thymeleaf.shiro.dialect.ShiroFacade;

import static at.pollux.thymeleaf.shiro.processor.AttributeUtils.getRawValue;

public class LacksRoleAttrProcessor extends AbstractConditionalVisibilityAttrProcessor {

    public static LacksRoleAttrProcessor create() {
        return new LacksRoleAttrProcessor();
    }

    private static final String ATTRIBUTE_NAME = "lacksRole";
    private static final int PRECEDENCE = 300;

    protected LacksRoleAttrProcessor() {
        super(ATTRIBUTE_NAME);
    }

    @Override
    public int getPrecedence() {
        return PRECEDENCE;
    }

    @Override
    public boolean isVisible(final Arguments arguments, final Element element, final String attributeName) {
        String role = getRawValue(element, attributeName);

        return ShiroFacade.lacksRole(role);
    }
}
